from pythonjsonlogger.orjson import OrjsonFormatter
from datetime import datetime, timezone


class CustomJsonFormatter(OrjsonFormatter):
    def add_fields(self, log_record, record, message_dict):
        super(CustomJsonFormatter, self).add_fields(
            log_record, record, message_dict)
        if not log_record.get('timestamp'):
            now = datetime.now(timezone.utc).strftime('%Y-%m-%dT%H:%M:%S.%fZ')
            log_record['timestamp'] = now
        if log_record.get('level'):
            log_record['level'] = log_record['level'].upper()
        else:
            log_record['level'] = record.levelname
        if log_record.get('correlation_id'):
            log_record['correlation_id'] = str(log_record['correlation_id'])


class AccessJsonFormatter(CustomJsonFormatter):
    def add_fields(self, log_record, record, message_dict):
        super(CustomJsonFormatter, self).add_fields(
            log_record, record, message_dict)
        [ip, method, path, protocol, status_code] = record.args
        log_record['client_addr'] = ip
        log_record["method"] = method
        log_record["path"] = path
        log_record["protocol"] = protocol
        log_record['status_code'] = status_code


formatter = CustomJsonFormatter('%(timestamp)s %(level)s %(name)s %(message)s')
